Overview
========

The `McAfee Active Response <http://www.mcafee.com/us/products/endpoint-threat-defense-response.aspx>`_ (MAR) DXL Python
client library provides a high level wrapper for the MAR
`Data Exchange Layer <http://www.mcafee.com/us/solutions/data-exchange-layer.aspx>`_ (DXL) API.

The purpose of this library is to allow users to perform MAR searches without having to focus
on lower-level details such as MAR-specific DXL topics and message formats.

The :class:`dxlmarclient.client.MarClient` class wraps the connection to the DXL fabric and is used to
execute MAR searches.

